@@ -1,12 +1,13 @@
 import json
 from pathlib import Path
+
 from dmiparser import DmiParser
 
 RDIR = Path(Path(__file__).resolve()).parents[0]
 
 
-def test_dmidecode_13():
-    testnum = 0
+def test_dmidecode_13() -> None:
+    count = 0
 
     with open(RDIR / "dmidecode_13.txt", "rt") as f:
         text = f.read()
@@ -19,6 +20,6 @@ def test_dmidecode_13():
         """
         if "0x000C" == d["handle"]["id"] and "BIOS Language Information" == d["name"]:
             assert 2 == len(d["props"]["Installable Languages"]["values"])
-            testnum += 1
+            count += 1
 
-    assert 1 == testnum
+    assert 1 == count
